import { PublicKey } from '@metaplex-foundation/umi';
import { AssetV1, CollectionV1 } from '../generated';
import { PluginAuthority } from '../plugins';
/**
 * Check if the given pubkey has the Address authority for the plugin.
 * @param {PublicKey | string} pubkey Pubkey
 * @param {PluginAuthority} authority Plugin authority
 * @returns {boolean} True if the pubkey has the authority
 */
export declare function hasPluginAddressAuthority(pubkey: PublicKey | string, authority: PluginAuthority): boolean;
/**
 * Check if the given pubkey has the Owner authority for the plugin.
 * @param {PublicKey | string} pubkey Pubkey
 * @param {PluginAuthority} authority Plugin authority
 * @param {AssetV1} asset Asset
 * @returns {boolean} True if the pubkey has the authority
 */
export declare function hasPluginOwnerAuthority(pubkey: PublicKey | string, authority: PluginAuthority, asset: AssetV1): boolean;
/**
 * Check if the given pubkey has the UpdateAuthority authority for the plugin.
 * @param {PublicKey | string} pubkey Pubkey
 * @param {PluginAuthority} authority Plugin authority
 * @param {AssetV1} asset Asset
 * @param {CollectionV1 | undefined} collection Collection
 * @returns {boolean} True if the pubkey has the authority
 */
export declare function hasPluginUpdateAuthority(pubkey: PublicKey | string, authority: PluginAuthority, asset: AssetV1, collection?: CollectionV1): boolean;
/**
 * Check if the given pubkey has the update authority for the asset.
 * If the asset specifies a collection as the update authority, the collection's update authority is checked.
 * If there are update delegates, they are also checked
 * @param {string | PublicKey} pubkey Pubkey
 * @param {AssetV1} asset Asset
 * @param {CollectionV1 | undefined} collection Collection
 * @returns {boolean} True if the pubkey is the update authority
 */
export declare function hasAssetUpdateAuthority(pubkey: string | PublicKey, asset: AssetV1, collection?: CollectionV1): boolean;
/**
 * CHeck if the given pubkey has update authority for the collection.
 * @param {string | PublicKey} pubkey Pubkey
 * @param {CollectionV1} collection Collection
 * @returns {boolean} True if the pubkey is the update authority
 */
export declare function hasCollectionUpdateAuthority(pubkey: string | PublicKey, collection: CollectionV1): boolean;
